@@ -682,7 +682,8 @@ also rebuild the xref database."
 (defun sepia-set-found (list &optional type)
   (setq list
 	(remove-if (lambda (x)
-		     (and (not (car x)) (string= (fourth x) "main")))
+                     (or (not x)
+                         (and (not (car x)) (string= (fourth x) "main"))))
 		   list))
   (setq sepia-found list
 	sepia-found-head list)
@@ -809,6 +810,11 @@ The function is intended to be bound to \\M-TAB, like
                           (t ""))
                         (and (not (eq major-mode 'comint-mode))
                              (sepia-function-at-point)))))
+      (when (and (not completions)
+                 (or (not type) (eq type ?&)))
+        (when (string-match ".*::([^:]+)$" name)
+          (setq name (match-string 1 name)))
+        (setq completions (all-completions name sepia-perl-builtins)))
       (case (length completions)
         (0 (message "No completions for %s." name) nil)
         (1 ;; (delete-ident-at-point)
@@ -1070,7 +1076,9 @@ calling ``cperl-describe-perl-symbol''."
     (multiple-value-bind (type obj) (sepia-ident-at-point)
       (when (consp obj)
         (setq obj (car obj)))
-      (if obj
+      (unless type
+        (setq type 'function))
+      (if (and obj (member type '(function variable module)))
         (or (gethash obj (ecase (or type 'function)
                            (function sepia-doc-map)
                            (variable sepia-var-doc-map)
@@ -1160,5 +1168,212 @@ calling ``cperl-describe-perl-symbol''."
     (t
      (concat "{" (mapconcat #'sepia-lisp-to-perl thing ", ") "}"))))
 
+(defvar sepia-perl-builtins
+  (eval-when-compile
+    (let ((h (make-hash-table)))
+      (dolist (s '("abs"
+"accept"
+"alarm"
+"atan2"
+"bind"
+"binmode"
+"bless"
+"caller"
+"chdir"
+"chmod"
+"chomp"
+"chop"
+"chown"
+"chr"
+"chroot"
+"close"
+"closedir"
+"connect"
+"continue"
+"cos"
+"crypt"
+"dbmclose"
+"dbmopen"
+"defined"
+"delete"
+"die"
+"dump"
+"each"
+"endgrent"
+"endhostent"
+"endnetent"
+"endprotoent"
+"endpwent"
+"endservent"
+"eof"
+"eval"
+"exec"
+"exists"
+"exit"
+"exp"
+"fcntl"
+"fileno"
+"flock"
+"fork"
+"format"
+"formline"
+"getc"
+"getgrent"
+"getgrgid"
+"getgrnam"
+"gethostbyaddr"
+"gethostbyname"
+"gethostent"
+"getlogin"
+"getnetbyaddr"
+"getnetbyname"
+"getnetent"
+"getpeername"
+"getpgrp"
+"getppid"
+"getpriority"
+"getprotobyname"
+"getprotobynumber"
+"getprotoent"
+"getpwent"
+"getpwnam"
+"getpwuid"
+"getservbyname"
+"getservbyport"
+"getservent"
+"getsockname"
+"getsockopt"
+"glob"
+"gmtime"
+"goto"
+"grep"
+"hex"
+"import"
+"index"
+"int"
+"ioctl"
+"join"
+"keys"
+"kill"
+"last"
+"lc"
+"lcfirst"
+"length"
+"link"
+"listen"
+"local"
+"localtime"
+"log"
+"lstat"
+"map"
+"mkdir"
+"msgctl"
+"msgget"
+"msgrcv"
+"msgsnd"
+"next"
+"oct"
+"open"
+"opendir"
+"ord"
+"pack"
+"package"
+"pipe"
+"pop"
+"pos"
+"print"
+"printf"
+"prototype"
+"push"
+"quotemeta"
+"rand"
+"read"
+"readdir"
+"readline"
+"readlink"
+"readpipe"
+"recv"
+"redo"
+"ref"
+"rename"
+"require"
+"reset"
+"return"
+"reverse"
+"rewinddir"
+"rindex"
+"rmdir"
+"scalar"
+"seek"
+"seekdir"
+"select"
+"semctl"
+"semget"
+"semop"
+"send"
+"setgrent"
+"sethostent"
+"setnetent"
+"setpgrp"
+"setpriority"
+"setprotoent"
+"setpwent"
+"setservent"
+"setsockopt"
+"shift"
+"shmctl"
+"shmget"
+"shmread"
+"shmwrite"
+"shutdown"
+"sin"
+"sleep"
+"socket"
+"socketpair"
+"sort"
+"splice"
+"split"
+"sprintf"
+"sqrt"
+"srand"
+"stat"
+"study"
+"sub"
+"sub*"
+"substr"
+"symlink"
+"syscall"
+"sysopen"
+"sysread"
+"sysseek"
+"system"
+"syswrite"
+"tell"
+"telldir"
+"tie"
+"tied"
+"time"
+"times"
+"truncate"
+"uc"
+"ucfirst"
+"umask"
+"undef"
+"unlink"
+"unpack"
+"unshift"
+"untie"
+"utime"
+"values"
+"vec"
+"wait"
+"waitpid"
+"wantarray"
+"warn"
+"write"
+))
+        (puthash s t h))
+      h)))
+
 (provide 'sepia)
 ;;; sepia.el ends here
